summaryrefslogtreecommitdiff
path: root/sources
diff options
context:
space:
mode:
authorpaltherr <paltherr@epfl.ch>2003-04-14 16:03:04 +0000
committerpaltherr <paltherr@epfl.ch>2003-04-14 16:03:04 +0000
commite51cf921ec19401f8e917255118a1a53e7c6520d (patch)
tree4026721e89129b2e3ae870959d70e1d8e135884c /sources
parent4503263fdad5875f2de09f34be947caca4dd210d (diff)
downloadscala-e51cf921ec19401f8e917255118a1a53e7c6520d.tar.gz
scala-e51cf921ec19401f8e917255118a1a53e7c6520d.tar.bz2
scala-e51cf921ec19401f8e917255118a1a53e7c6520d.zip
- Renamed TreeCopyFactory in TreeCopier
- Renamed AbstractTreeCopyFactory in AbstractTreeCopier Renamed - LazyTreeFactory in LazyTreeCopier Renamed StrictTreeFactory in - StrictTreeCopier
Diffstat (limited to 'sources')
-rw-r--r--sources/scalac/ast/AbstractTreeCopyFactory.java6
-rw-r--r--sources/scalac/ast/LazyTreeFactory.java4
-rw-r--r--sources/scalac/ast/StrictTreeFactory.java4
-rw-r--r--sources/scalac/ast/SubstTransformer.java6
-rw-r--r--sources/scalac/ast/Transformer.java14
-rw-r--r--sources/scalac/ast/Tree.java2
-rw-r--r--sources/scalac/ast/TreeCopyFactory.java2
-rw-r--r--sources/scalac/typechecker/DeSugarize.java2
8 files changed, 20 insertions, 20 deletions
diff --git a/sources/scalac/ast/LazyTreeFactory.java b/sources/scalac/ast/LazyTreeFactory.java
index 4f81a103f8..701ffc69a7 100644
--- a/sources/scalac/ast/LazyTreeFactory.java
+++ b/sources/scalac/ast/LazyTreeFactory.java
@@ -11,10 +11,10 @@ package scalac.ast;
import scalac.util.Name;
import Tree.*;
-public class LazyTreeFactory extends AbstractTreeCopyFactory {
+public class LazyTreeCopier extends AbstractTreeCopier {
protected final TreeFactory make;
- public LazyTreeFactory(TreeFactory make) {
+ public LazyTreeCopier(TreeFactory make) {
this.make = make;
}
diff --git a/sources/scalac/ast/StrictTreeFactory.java b/sources/scalac/ast/StrictTreeFactory.java
index e047ca7265..8abfa3e811 100644
--- a/sources/scalac/ast/StrictTreeFactory.java
+++ b/sources/scalac/ast/StrictTreeFactory.java
@@ -13,10 +13,10 @@ package scalac.ast;
import scalac.util.Name;
import Tree.*;
-public class StrictTreeFactory extends AbstractTreeCopyFactory {
+public class StrictTreeCopier extends AbstractTreeCopier {
protected final TreeFactory make;
- public StrictTreeFactory(TreeFactory make) {
+ public StrictTreeCopier(TreeFactory make) {
this.make = make;
}
diff --git a/sources/scalac/ast/SubstTransformer.java b/sources/scalac/ast/SubstTransformer.java
index 038a7a934b..fbfd53411d 100644
--- a/sources/scalac/ast/SubstTransformer.java
+++ b/sources/scalac/ast/SubstTransformer.java
@@ -42,11 +42,11 @@ public class SubstTransformer extends Transformer {
}
};
- protected final TreeCopyFactory simpleCopy;
+ protected final TreeCopier simpleCopy;
public SubstTransformer(Global global, TreeFactory make) {
super(global, make, new TCF(make));
- this.simpleCopy = new StrictTreeFactory(make);
+ this.simpleCopy = new StrictTreeCopier(make);
((TCF)copy).setTransformer(this);
}
@@ -210,7 +210,7 @@ public class SubstTransformer extends Transformer {
//////////////////////////////////////////////////////////////////////
- public static class TCF extends StrictTreeFactory {
+ public static class TCF extends StrictTreeCopier {
protected SubstTransformer transformer;
protected Map/*<Symbol,Symbol>*/ symbolMap;
protected SymbolMapApplier smApplier;
diff --git a/sources/scalac/ast/Tree.java b/sources/scalac/ast/Tree.java
index 7ed9f2da8a..1ab1761289 100644
--- a/sources/scalac/ast/Tree.java
+++ b/sources/scalac/ast/Tree.java
@@ -913,7 +913,7 @@ public class Tree {
public static Transformer duplicator =
new Transformer(
Global.instance, Global.instance.make,
- new StrictTreeFactory(Global.instance.make));
+ new StrictTreeCopier(Global.instance.make));
public Tree duplicate() {
return duplicator.transform(this);
diff --git a/sources/scalac/ast/TreeCopyFactory.java b/sources/scalac/ast/TreeCopyFactory.java
index 69f82aa6ca..d1df6fc91e 100644
--- a/sources/scalac/ast/TreeCopyFactory.java
+++ b/sources/scalac/ast/TreeCopyFactory.java
@@ -18,7 +18,7 @@ import Tree.*;
* @author Michel Schinz
* @version 1.1
*/
-public interface TreeCopyFactory {
+public interface TreeCopier {
public void attribute(Tree newTree, Tree oldTree);
diff --git a/sources/scalac/typechecker/DeSugarize.java b/sources/scalac/typechecker/DeSugarize.java
index 3b490178f5..508f797b11 100644
--- a/sources/scalac/typechecker/DeSugarize.java
+++ b/sources/scalac/typechecker/DeSugarize.java
@@ -34,7 +34,7 @@ public class DeSugarize implements Kinds, Modifiers {
/** The copying factory
*/
- protected TreeCopyFactory copy;
+ protected TreeCopier copy;
/** the tree generator
*/
diff --git a/sources/scalac/ast/AbstractTreeCopyFactory.java b/sources/scalac/ast/AbstractTreeCopyFactory.java
index 358d468cd4..0a158e14d4 100644
--- a/sources/scalac/ast/AbstractTreeCopyFactory.java
+++ b/sources/scalac/ast/AbstractTreeCopyFactory.java
@@ -12,14 +12,14 @@ package scalac.ast;
import scalac.ast.*;
/**
* Abstract superclass for all TreeCopyFactories, which provides only
* the code to copy the attribution from the "old" to the "new" tree.
*
* @author Michel Schinz
* @version 1.0
*/
-public abstract class AbstractTreeCopyFactory implements TreeCopyFactory {
+public abstract class AbstractTreeCopier implements TreeCopier {
public void attribute(Tree newTree, Tree oldTree) {
if (newTree != oldTree) {
newTree.type = oldTree.type;
@@ -12,14 +12,14 @@ package scalac.ast;
import scalac.ast.*;
/**
- * Abstract superclass for all TreeCopyFactories, which provides only
- * the code to copy the attribution from the "old" to the "new" tree.
+ * Abstract superclass for all TreeCopier, which provides only the
+ * code to copy the attribution from the "old" to the "new" tree.
*
* @author Michel Schinz
diff --git a/sources/scalac/ast/Transformer.java b/sources/scalac/ast/Transformer.java
index 2d9f7b0ce4..60c933d833 100644
--- a/sources/scalac/ast/Transformer.java
+++ b/sources/scalac/ast/Transformer.java
@@ -32,11 +32,11 @@ public class Transformer {
*/
public final TreeFactory make;
/** a factory for copying trees; the attribution is preserved
* or translated according to the TreeCopyFactory; trees are
* only copied if new tree introduces changes
*/
- public final TreeCopyFactory copy;
+ public final TreeCopier copy;
/** a tree generator
*/
@@ -45,14 +45,14 @@ public class Transformer {
/** various constructors
*/
public Transformer(Global global) {
- this(global, global.make, new LazyTreeFactory(global.make));
+ this(global, global.make, new LazyTreeCopier(global.make));
}
public Transformer(Global global, TreeFactory make) {
- this(global, make, new LazyTreeFactory(make));
+ this(global, make, new LazyTreeCopier(make));
}
- public Transformer(Global global, TreeFactory make, TreeCopyFactory copy) {
+ public Transformer(Global global, TreeFactory make, TreeCopier copy) {
this.global = global;
this.make = make;
this.copy = copy;
@@ -32,11 +32,11 @@ public class Transformer {
*/
public final TreeFactory make;
- /** a factory for copying trees; the attribution is preserved
- * or translated according to the TreeCopyFactory; trees are
- * only copied if new tree introduces changes
+ /** a factory for copying trees; the attribution is preserved or
+ * translated according to the TreeCopier; trees are only copied
+ * if new tree introduces changes
*/